@@ -45,8 +45,8 @@ namespace MiX{
   template <class charT,class char_traits,class xml_traits>
   XMLString<charT,char_traits,xml_traits> Element<charT,char_traits,xml_traits>::getFullName() const {
     string_type name;
-    if( !getURL().empty() ) {
-      string_type nsn = queryNSName( getURL() );
+    if( !getURI().empty() ) {
+      string_type nsn = queryPrefix( getURI() );
       if( !nsn.empty() ){
 	name = nsn + xml_traits::colon();
       }
@@ -102,12 +102,12 @@ namespace MiX{
   template <class charT,class char_traits,class xml_traits>
   Node<charT,char_traits,xml_traits>& Element<charT,char_traits,xml_traits>::clone(nodecontainer_type& parent,const nodelist_iter& it) const {
     element_type* ret = new this_type(getName());
-    ret->setURL(getURL());
+    ret->setURL(getURI());
     ret->setParent(parent);
     if(&it==&dmy_it)
       parent.getChildren().insert(parent.getChildren().end(),ret);
     else parent.getChildren().insert(it,ret);
-    //element_type& ret = create(getName(),getURL(),parent,it);
+    //element_type& ret = create(getName(),getURI(),parent,it);
     cloneChildren(*ret);
     return *ret;
   }
