@@ -2,14 +2,6 @@
 #ifndef MiX_MISC_H_
 #define MiX_MISC_H_
 
-// Adlib/misc.h
-// (C) Copyright KUBO,Yotaro.
-// [o[W]
-// 0.4.7
-//   - Oo[W̃ev[gp[^̉ɖ߂
-//   - IncludeGuard}N̕ύX]
-
-
 /** \file misc
  *   ɒuĂ̂͂Ő錾Ă܂
  */
@@ -51,14 +43,25 @@ namespace MiX{
     NullException,
     NodeNotFound,
     NodeDuplication,
-    InvalidNodeFound
+    InvalidNodeFound,
+    NamespaceNotDefined,
+    // for XPathException
+    InvalidXPathResult,
+    InvalidDocument
   };
 
   /// toStringȂǂŗp镶Ɏw萔tabǉ֐ł
   template<class charT,class traitsT>
+  XMLString<charT,traitsT> make_indent(int off,const XMLString<charT,traitsT>& idt){
+    XMLString<charT,traitsT> ret;
+    for( int i=0 ; i<off ; ++i ) ret+=idt;
+    return ret;
+  }
+  /*
+  template<class charT,class traitsT>
   void insertIndent(int i,XMLString<charT,traitsT>& str,charT c){
     for(int j=0;j<i;j++) str+=c;
-  }
+    }*/
 
 
 #define MiX_Template_Typedef(C,T,X) typedef C char_type; \
@@ -76,7 +79,10 @@ namespace MiX{
     typedef AttrMap<C,T,X> attrmap_type; \
     typedef XMLString<C,T,X> string_type; \
     typedef NodeList<C,T,X> nodelist_type; \
-    typedef DOM_Exception<C,T,X> dom_exception_type
+    typedef DOM_Exception<C,T,X> dom_exception_type; \
+    typedef XPathAtom<C,T,X> xpathatom_type; \
+    typedef XPathResult<C,T,X> xpathresult_type;	\
+    typedef XPathException<C,T,X> xpathexception_type
 }
 
 #endif
