@@ -31,7 +31,7 @@ private:
   void testImpl(MiX::Document<char>& doc) {
     CPPUNIT_ASSERT_EQUAL( T("1.0"), doc["version"].getValue() );
     CPPUNIT_ASSERT_EQUAL( T("book"), doc.getRoot().getName() );
-    CPPUNIT_ASSERT_EQUAL( T(URL_BOOK), doc.getRoot().getURL() );
+    CPPUNIT_ASSERT_EQUAL( T(URL_BOOK), doc.getRoot().getURI() );
     CPPUNIT_ASSERT_EQUAL( T("Cheaper by the Dozen"),
 			  doc.getRoot()("title",URL_BOOK).getText() );
     CPPUNIT_ASSERT_EQUAL( T("1568491379"),
